Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ParseError ¶
ParseError is an error, representing not being able to parse GraphQL request.
func (ParseError) Error ¶
func (e ParseError) Error() string
func (ParseError) Unwrap ¶
func (e ParseError) Unwrap() error
type QueryInfo ¶
type QueryInfo struct {
Type string `json:"type"` // Request type (query, mutation, subscription)
Name string `json:"name"` // Request name
Parameters map[string]string `json:"parameters"` // Request params (type of requested variables)
Variables map[string]any `json:"variables"` // Request variables for query
Fields []FieldInfo `json:"fields"` // List of requested fields, including input variables
}
QueryInfo represents information about GraphQL query, it's params and variables.
func ParseQuery ¶
ParseQuery parses GraphQL-request and returns info about it.
type RequestBody ¶ added in v1.9.3
RequestBody represents information about Request Body for later parsing.
Click to show internal directories.
Click to hide internal directories.